import React from 'react';

var Icon = function (props) {
    var _a;
    return (React.createElement("span", { onClick: function () {
            props.onClick && props.onClick();
        }, className: "material-symbols-outlined ".concat((_a = props.color) !== null && _a !== void 0 ? _a : '') }, props.icon));
};

var IconStyles;
(function (IconStyles) {
    IconStyles["home"] = "home";
    IconStyles["menu"] = "menu";
    IconStyles["menuOpen"] = "menu_open";
    IconStyles["monitoring"] = "monitoring";
    IconStyles["palette"] = "palette";
    IconStyles["info"] = "info";
    IconStyles["search"] = "search";
    IconStyles["cancel"] = "cancel";
    IconStyles["login"] = "login";
    IconStyles["logout"] = "logout";
    IconStyles["add"] = "add";
    IconStyles["remove"] = "remove";
    IconStyles["close"] = "close";
    IconStyles["list"] = "list";
})(IconStyles || (IconStyles = {}));
var IconColors;
(function (IconColors) {
    IconColors["primary"] = "primary";
    IconColors["onPrimaryContainer"] = "on-primary-container";
    IconColors["onSurfaceVariant"] = "on-surface-variant";
})(IconColors || (IconColors = {}));

var IconVariants = /*#__PURE__*/Object.freeze({
    __proto__: null,
    get IconStyles () { return IconStyles; },
    get IconColors () { return IconColors; }
});

var Button = function (props) {
    return (React.createElement("button", { className: props.disabled
            ? props.iconOnly
                ? "icon-button disabled"
                : "button ".concat(props.type, " disabled")
            : props.iconOnly
                ? "icon-type"
                : "button ".concat(props.type), onClick: function () {
            props.onClick();
        } },
        props.icon ? React.createElement(Icon, { icon: props.icon }) : '',
        !props.iconOnly && React.createElement("span", null, props.text)));
};

var ButtonStyles;
(function (ButtonStyles) {
    ButtonStyles["filled"] = "button-filled";
    ButtonStyles["elevated"] = "button-elevated";
    ButtonStyles["tonal"] = "button-tonal";
    ButtonStyles["outlined"] = "button-outlined";
    ButtonStyles["text"] = "button-text";
    ButtonStyles["title"] = "button-title";
})(ButtonStyles || (ButtonStyles = {}));

var ButtonVariants = /*#__PURE__*/Object.freeze({
    __proto__: null,
    get ButtonStyles () { return ButtonStyles; }
});

var Dialog = function (props) {
    return (React.createElement("div", { className: "modal-container" },
        React.createElement("div", { className: "modal-header" },
            React.createElement("div", { className: "header-text" }, props.header),
            React.createElement("div", { className: "close-button-container" },
                React.createElement("div", { className: "close-button", onClick: props.handleClose },
                    React.createElement(Icon, { icon: IconStyles.close })))),
        React.createElement("div", { className: "modal-content" }, props.content),
        React.createElement("div", { className: "modal-footer" }, props.footer)));
};

var Drawer = function (props) {
    return (React.createElement(React.Fragment, null,
        React.createElement("nav", { className: props.isOpen ? 'drawer drawer--open' : 'drawer' },
            React.createElement("div", { className: "drawer-content-top" }, props.drawerContentTop),
            React.createElement("div", { className: "drawer-content-bottom" }, props.drawerContentBottom)),
        React.createElement("div", { className: props.isOpen
                ? 'drawer-background drawer-background--open'
                : 'drawer-background', onClick: props.handleCloseDrawer })));
};

var DrawerItem = function (props) {
    var handleClick = function (event) {
        event.preventDefault();
        props.onClick();
    };
    return (React.createElement("a", { className: props.match == undefined
            ? 'drawer-item'
            : props.match
                ? 'drawer-item active'
                : 'drawer-item', onClick: handleClick },
        React.createElement("span", { className: "state-layer" },
            React.createElement("span", { className: props.label ? 'icon-container has-label' : 'icon-container' },
                React.createElement(Icon, { icon: props.icon })),
            props.label && React.createElement("div", { className: "drawer-label" }, props.label))));
};

var LoadingSpinner = function (props) { return (React.createElement("div", { className: "loading ".concat(props.size) },
    React.createElement("svg", { className: "circular", viewBox: "25 25 50 50" },
        React.createElement("circle", { cx: 50, cy: 50, r: "20", stroke: "black", fill: "none", strokeWidth: 3.6 })))); };

var LoadingSpinnerSizes;
(function (LoadingSpinnerSizes) {
    LoadingSpinnerSizes["small"] = "small";
    LoadingSpinnerSizes["large"] = "large";
})(LoadingSpinnerSizes || (LoadingSpinnerSizes = {}));

var LoadingSpinnerVariants = /*#__PURE__*/Object.freeze({
    __proto__: null,
    get LoadingSpinnerSizes () { return LoadingSpinnerSizes; }
});

var SideNav = function (props) {
    return (React.createElement("div", { className: "side-nav" },
        React.createElement("section", { className: "side-nav-top" }, props.topSection),
        React.createElement("section", { className: "side-nav-bottom" }, props.bottomSection)));
};

var SideNavItem = function (props) {
    var handleClick = function (event) {
        event.preventDefault();
        props.onClick();
    };
    return (React.createElement("a", { className: props.match == undefined
            ? 'nav-item'
            : props.match
                ? 'nav-item active'
                : 'nav-item', onClick: handleClick },
        React.createElement("span", { className: props.label ? 'icon-container has-label' : 'icon-container' },
            React.createElement("span", { className: "state-layer" },
                React.createElement(Icon, { icon: props.icon }))),
        props.label && React.createElement("div", { className: "nav-label" }, props.label)));
};

var TextInput = function (props) {
    var _a, _b;
    var _c = React.useState(false), active = _c[0], setActive = _c[1];
    var handleClick = function () {
        var input = document.getElementById(props.id);
        input === null || input === void 0 ? void 0 : input.focus();
    };
    var defaultEventHandler = function (event) {
        event.preventDefault();
    };
    return (React.createElement("div", { className: props.disabled
            ? "text-input ".concat(props.inputStyle, " disabled")
            : active
                ? "text-input ".concat(props.inputStyle, " active")
                : "text-input ".concat(props.inputStyle), onClick: handleClick },
        React.createElement("div", { className: "text-input-content" },
            props.icon && (React.createElement("div", { className: "icon-container" },
                React.createElement(Icon, { icon: props.icon, color: IconColors.onSurfaceVariant }))),
            React.createElement("div", { className: "text-input-container" },
                React.createElement("label", { className: active || props.value
                        ? props.icon
                            ? "".concat(props.background, " has-icon active")
                            : "".concat(props.background, " active")
                        : props.icon
                            ? "".concat(props.background, " has-icon")
                            : "".concat(props.background) }, props.label),
                React.createElement("input", { id: props.id, value: props.value, type: props.type, className: active || props.value ? 'active' : '', onInput: (_a = props.onInput) !== null && _a !== void 0 ? _a : defaultEventHandler, onKeyUp: (_b = props.onKeyUp) !== null && _b !== void 0 ? _b : defaultEventHandler, placeholder: active ? props.placeholder : '', onFocus: function () { return setActive(true); }, onBlur: function () { return setActive(false); } })))));
};

var TextInputStyles;
(function (TextInputStyles) {
    TextInputStyles["filled"] = "filled";
    TextInputStyles["outlined"] = "outlined";
})(TextInputStyles || (TextInputStyles = {}));
var TextInputColors;
(function (TextInputColors) {
    TextInputColors["surface"] = "surface";
    TextInputColors["tintedSurface"] = "tinted-surface";
})(TextInputColors || (TextInputColors = {}));

var TextInputVariants = /*#__PURE__*/Object.freeze({
    __proto__: null,
    get TextInputStyles () { return TextInputStyles; },
    get TextInputColors () { return TextInputColors; }
});

var TopNav = function (props) {
    return (React.createElement("div", { className: "top-nav" },
        React.createElement("section", { className: "top-nav-left" }, props.leftSection),
        React.createElement("section", { className: "top-nav-right" }, props.rightSection)));
};

var TopNavItem = function (props) {
    var handleClick = function (event) {
        event.preventDefault();
        props.onClick();
    };
    return (React.createElement("a", { className: props.match == undefined
            ? 'top-nav-item'
            : props.match
                ? 'top-nav-item active'
                : 'top-nav-item', onClick: handleClick },
        React.createElement("span", { className: props.label ? 'icon-container has-label' : 'icon-container' },
            React.createElement("span", { className: "state-layer" },
                React.createElement(Icon, { icon: props.icon }))),
        props.label && React.createElement("div", { className: "nav-label" }, props.label)));
};

export { Button, ButtonVariants, Dialog, Drawer, DrawerItem, Icon, IconVariants, LoadingSpinner, LoadingSpinnerVariants, SideNav, SideNavItem, TextInput, TextInputVariants, TopNav, TopNavItem };
//# sourceMappingURL=index.js.map
