/// <reference types="react" />
import { FC, MouseEventHandler, FormEventHandler, KeyboardEventHandler } from 'react';

declare enum ButtonStyles {
    filled = "button-filled",
    elevated = "button-elevated",
    tonal = "button-tonal",
    outlined = "button-outlined",
    text = "button-text",
    title = "button-title"
}

type ButtonVariants_d_ButtonStyles = ButtonStyles;
declare const ButtonVariants_d_ButtonStyles: typeof ButtonStyles;
declare namespace ButtonVariants_d {
  export {
    ButtonVariants_d_ButtonStyles as ButtonStyles,
  };
}

declare enum IconStyles {
    home = "home",
    menu = "menu",
    menuOpen = "menu_open",
    monitoring = "monitoring",
    palette = "palette",
    info = "info",
    search = "search",
    cancel = "cancel",
    login = "login",
    logout = "logout",
    add = "add",
    remove = "remove",
    close = "close",
    list = "list"
}
declare enum IconColors {
    primary = "primary",
    onPrimaryContainer = "on-primary-container",
    onSurfaceVariant = "on-surface-variant"
}

type IconVariants_d_IconStyles = IconStyles;
declare const IconVariants_d_IconStyles: typeof IconStyles;
type IconVariants_d_IconColors = IconColors;
declare const IconVariants_d_IconColors: typeof IconColors;
declare namespace IconVariants_d {
  export {
    IconVariants_d_IconStyles as IconStyles,
    IconVariants_d_IconColors as IconColors,
  };
}

interface IconProps {
    icon: IconStyles;
    color?: IconColors;
    onClick?: Function;
}

declare const Icon: FC<IconProps>;

interface ButtonProps {
    type: ButtonStyles;
    text: string;
    onClick: Function;
    icon?: IconStyles;
    iconOnly?: boolean;
    disabled?: boolean;
}

declare const Button: FC<ButtonProps>;

interface DialogProps {
    header: string;
    content: JSX.Element;
    footer: JSX.Element;
    handleClose: MouseEventHandler;
}

declare const Dialog: FC<DialogProps>;

interface DrawerProps {
    isOpen: boolean;
    handleCloseDrawer: MouseEventHandler;
    drawerContentBottom?: JSX.Element;
    drawerContentTop?: JSX.Element;
}

declare const Drawer: FC<DrawerProps>;

interface DrawerItemProps {
    icon: IconStyles;
    onClick: Function;
    label?: string;
    match?: boolean;
}

declare const DrawerItem: FC<DrawerItemProps>;

declare enum LoadingSpinnerSizes {
    small = "small",
    large = "large"
}

type LoadingSpinnerVariants_d_LoadingSpinnerSizes = LoadingSpinnerSizes;
declare const LoadingSpinnerVariants_d_LoadingSpinnerSizes: typeof LoadingSpinnerSizes;
declare namespace LoadingSpinnerVariants_d {
  export {
    LoadingSpinnerVariants_d_LoadingSpinnerSizes as LoadingSpinnerSizes,
  };
}

interface LoadingSpinnerProps {
    size: LoadingSpinnerSizes;
}

declare const LoadingSpinner: FC<LoadingSpinnerProps>;

interface SideNavProps {
    topSection?: JSX.Element;
    bottomSection?: JSX.Element;
}

declare const SideNav: FC<SideNavProps>;

interface SideNavItemProps {
    icon: IconStyles;
    onClick: Function;
    label?: string;
    match?: boolean;
}

declare const SideNavItem: FC<SideNavItemProps>;

declare enum TextInputStyles {
    filled = "filled",
    outlined = "outlined"
}
declare enum TextInputColors {
    surface = "surface",
    tintedSurface = "tinted-surface"
}

type TextInputVariants_d_TextInputStyles = TextInputStyles;
declare const TextInputVariants_d_TextInputStyles: typeof TextInputStyles;
type TextInputVariants_d_TextInputColors = TextInputColors;
declare const TextInputVariants_d_TextInputColors: typeof TextInputColors;
declare namespace TextInputVariants_d {
  export {
    TextInputVariants_d_TextInputStyles as TextInputStyles,
    TextInputVariants_d_TextInputColors as TextInputColors,
  };
}

interface TextInputProps {
    id: string;
    label: string;
    value: string;
    onInput: FormEventHandler<HTMLInputElement>;
    inputStyle: TextInputStyles;
    background: TextInputColors;
    placeholder?: string;
    onKeyUp?: KeyboardEventHandler<HTMLInputElement>;
    type?: string;
    icon?: IconStyles;
    disabled?: boolean;
}

declare const TextInput: FC<TextInputProps>;

interface TopNavProps {
    leftSection?: JSX.Element;
    rightSection?: JSX.Element;
}

declare const TopNav: FC<TopNavProps>;

interface TopNavItemProps {
    icon: IconStyles;
    onClick: Function;
    label?: string;
    match?: boolean;
}

declare const TopNavItem: FC<TopNavItemProps>;

export { Button, ButtonVariants_d as ButtonVariants, Dialog, Drawer, DrawerItem, Icon, IconVariants_d as IconVariants, LoadingSpinner, LoadingSpinnerVariants_d as LoadingSpinnerVariants, SideNav, SideNavItem, TextInput, TextInputVariants_d as TextInputVariants, TopNav, TopNavItem };
