import resolve from '@rollup/plugin-node-resolve'
import commonjs from '@rollup/plugin-commonjs'
import typescript from '@rollup/plugin-typescript'
import external from 'rollup-plugin-peer-deps-external'
import dts from 'rollup-plugin-dts'
import scss from 'rollup-plugin-scss'
import bundleScss from 'rollup-plugin-bundle-scss'

import packageJson from './package.json' assert { type: 'json' }

export default [
  {
    input: 'src/index.ts',
    output: [
      {
        file: packageJson.main,
        format: 'cjs',
        sourcemap: true,
        name: 'm3-react',
      },
      {
        file: packageJson.module,
        format: 'esm',
        sourcemap: true,
      },
    ],
    plugins: [
      external(),
      resolve(),
      commonjs(),
      typescript({ tsconfig: './tsconfig.json' }),
      // bundleScss({ output: 'styles/_components.scss', exclusive: false }),
      scss({
        include: ['./src/components/**/*.scss'],
        prefix: `@import "./src/_variables.scss"; @import "./src/_resets.scss";`,
        output: 'dist/styles.css',
        failOnError: true,
      }),
    ],
  },
  {
    input: 'dist/esm/index.d.ts',
    output: [{ file: 'dist/index.d.ts', format: 'esm' }],
    plugins: [dts()],
    external: [/\.scss$/], // ignore .scss file
  },
]
